#!/bin/bash

# This helper script will handle deploying a dynamodb table
#
# /scripts/deploy-dynamodb.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

append_iam_roles_from_env_to_tf_vars "read-only-role" "read_only_roles" "${tfAdditionalVarsFile}"
append_iam_roles_from_env_to_tf_vars "read-write-role" "read_write_roles" "${tfAdditionalVarsFile}"

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn

terraform_get arn arnValue
terraform_get stream_arn streamArnValue
terraform_get read_only_policy readOnlyPolicyValue
terraform_get read_write_policy readWritePolicyValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  streamArn: ${streamArnValue}
  ReadOnlyPolicy: ${readOnlyPolicyValue}
  ReadWritePolicy: ${readWritePolicyValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
